<?php

namespace App\Http\Swagger;

/**
 * @OA\Tag(
 *     name="Search Flight Offers",
 *     description="Fetches combined flight offers based on search criteria (oneway or roundtrip)"
 * )
 * 
 * @OA\Post(
 *     path="/api/ama/combined_offers",
 *     summary="Query Flight Offers",
 *     tags={"Search Flight Offers"},
 *     description="Fetches combined flight offers based on search criteria (oneway or roundtrip).",
 *     @OA\RequestBody(
 *         required=true,
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                  property="CabinPreference", 
 *                  type="object",
 *                  @OA\Property(property="@type", type="string", example="CabinPreference", description="Type of the object"),
 *                  @OA\Property(property="preferenceType", type="string", example="Preferred", description="Cabin preference type"),
 *                  @OA\Property(
 *                      property="cabins", 
 *                      type="array", 
 *                      @OA\Items(type="string"), 
 *                      description="List of cabin preferences",
 *                      example={"Economy"}
 *                  )
 *             ),
 *             @OA\Property(property="source", type="array", @OA\Items(type="string"), example={"GDS", "NDC"}, description="Sources of the offer"),
 *             @OA\Property(property="carrier", type="array", @OA\Items(type="string"), example={}, description="Preferred carrier(s)"),
 *             @OA\Property(property="flightType", type="object", 
 *                 @OA\Property(property="connectionType", type="string", example="NonStopDirect", description="Flight connection type")
 *             ),
 *             @OA\Property(property="isFlexibleDates", type="string", example="true", description="Flexibility of dates"),
 *             @OA\Property(property="passengerCriteria", type="array", 
 *                 @OA\Items(
 *                     type="object",
 *                     @OA\Property(property="@type", type="string", example="PassengerCriteria", description="Type of the passenger criteria"),
 *                     @OA\Property(property="number", type="string", example="2", description="Number of passengers"),
 *                     @OA\Property(property="passengerTypeCode", type="string", example="ADT", description="Passenger type code")
 *                 )
 *             ),
 *             @OA\Property(property="searchCriteriaFlight", type="array", 
 *                 @OA\Items(
 *                     type="object",
 *                     @OA\Property(property="@type", type="string", example="SearchCriteriaFlight", description="Type of the flight search criteria"),
 *                     @OA\Property(property="departureDate", type="string", example="2024-11-01", description="Date of departure"),
 *                     @OA\Property(property="From", type="object",
 *                         @OA\Property(property="value", type="string", example="LON", description="Departure city or airport code")
 *                     ),
 *                     @OA\Property(property="To", type="object",
 *                         @OA\Property(property="value", type="string", example="SIN", description="Arrival city or airport code")
 *                     )
 *                 ),
 *                 description="Roundtrip flight search criteria",
 *                 example={
 *                     {
 *                         "@type": "SearchCriteriaFlight",
 *                         "departureDate": "2024-11-01",
 *                         "From": {"value": "LON"},
 *                         "To": {"value": "SIN"}
 *                     },
 *                     {
 *                         "@type": "SearchCriteriaFlight",
 *                         "departureDate": "2024-11-30",
 *                         "From": {"value": "SIN"},
 *                         "To": {"value": "LON"}
 *                     }
 *                 }
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="productOffers", type="array", @OA\Items(type="object")),
 *             @OA\Property(property="total_combined_offers", type="integer"),
 *             @OA\Property(property="offers_request_id", type="string"),
 *             @OA\Property(property="offersGroup", type="array", @OA\Items(type="object")),
 *             @OA\Property(property="errorMessage", type="string"),
 *             @OA\Property(property="amadeusSessionId", type="string"),
 *             @OA\Property(property="amadeusSecurityToken", type="string"),
 *         )
 *     ),
 *     @OA\Response(
 *         response=400,
 *         description="Bad Request",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="error_message", type="string")
 *         )
 *     )
 * )
 */
class ACombinedOffers
{
    // This class is just for holding Swagger annotations
}
