<?php

namespace App\Http\Swagger;

/**
 * @OA\Tag(
 *     name="NDC",
 *     description="NDC contents flow"
 * )
 * 
 * @OA\Post(
 *      path="/api/ama/ndc_travel_offer_price",
 *      summary="NDC - Travel Offer Price",
 *      tags={"NDC"},
 *      description="Selected NDC offer pricing and retrieve Upsell Offers.",
 *      @OA\RequestBody(
 *          required=true,
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(
 *                  property="ShoppingResponseRefID",
 *                  type="string",
 *                  example="SP2F-1952803286450754438",
 *                  description="offersGroup > response > applicationDetails > internalId"
 *              ),
 *              @OA\Property(
 *                  property="ShoppingOwnerCode",
 *                  type="string",
 *                  example="SQ",
 *                  description="productAir > itemNumber > codeShareDetails > company"
 *              ),
 *              @OA\Property(
 *                  property="OfferRefID",
 *                  type="string",
 *                  example="TOUITBWdcCQYC~38jB~uHPRA.216_1A_c4972b41-739f-45fe-b2a2-ce15e2647839_1A_SP2F-1952803286450754438-1",
 *                  description="offersGroup > offers > offerDetails > uniqueOfferReference"
 *              ),
 *              @OA\Property(
 *                  property="OfferItems",
 *                  type="object",
 *                  @OA\Property(
 *                      property="offerItemDetails",
 *                      type="object",
 *                      @OA\Property(
 *                          property="offerItemId",
 *                          type="string",
 *                          example="SP2F-1952803286450754438-1-1",
 *                          description=""
 *                      )
 *                  ),
 *                  @OA\Property(
 *                      property="paxReference", 
 *                      type="object",
 *                      @OA\Property(
 *                          property="ptc",
 *                          type="string",
 *                          example="ADT",
 *                          description=""
 *                      ),
 *                      @OA\Property(
 *                          property="traveller",
 *                          type="array",
 *                          @OA\Items(
 *                              type="object",
 *                              @OA\Property(
 *                                  property="ref", 
 *                                  type="string", 
 *                                  example="1", 
 *                                  description="PTC Reference ID"
 *                              )
 *                          ),
 *                          description="[traveller] property could be array or object. If same type has more than one pax this should be array type and other wise this should be object type.",
 *                          example={
 *                              {
 *                                  "ref": "1"
 *                              },
 *                              {
 *                                  "ref": "2"
 *                              }
 *                          }
 *                      ),
 *                  ),
 *              ),
 *          )
 *      ),
 *      @OA\Response(
 *          response=200,
 *          description="Successful operation",
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(
 *                  property="amaReply", 
 *                  type="object", 
 *                  @OA\Property(
 *                      property="DataLists",
 *                      type="object",
 *                      @OA\Property(
 *                          property="BaggageAllowanceList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="FareList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="OriginDestList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="PaxJourneyList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="PaxList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="PaxSegmentList",
 *                          type="object"
 *                       ),
 *                      @OA\Property(
 *                          property="PriceClassList",
 *                          type="object"
 *                       ),
 *                  ),
 *                  @OA\Property(
 *                      property="Metadata",
 *                      type="array",
 *                      @OA\Items(
 *                          type="object"
 *                      )
 *                  ),
 *                  @OA\Property(
 *                      property="PricedOffer",
 *                      type="object",
 *                      @OA\Property(
 *                          property="Offer",
 *                          type="object",
 *                          description="Selected offer with price details"
 *                      ),
 *                  ),
 *                  @OA\Property(
 *                      property="OtherOffers",
 *                      type="object",
 *                      @OA\Property(
 *                          property="Offer",
 *                          type="array",
 *                          description="Upsell offers with price details",
 *                          @OA\Items(
 *                              type="object"
 *                          )
 *                      ),
 *                  ),
 *                  @OA\Property(
 *                      property="ShoppingResponse",
 *                      type="object"
 *                  ),
 *              )
 *          )
 *      ),
 *      @OA\Response(
 *          response=400,
 *          description="Bad Request",
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(property="error_message", type="string")
 *          )
 *      )
 * )
 */

class NDC_2TravelOfferPrice
{
    //
}
